
/*
 * *****************************************************************************************
 *
 * 		Copyright (C) 2014-2019 Gowin Semiconductor Technology Co.,Ltd.
 * 		
 * @file		main.c
 * @author		Embedded Development Team
 * @version		V1.3.0
 * @date		2019-10-1 09:00:00
 * @brief		Main program body.
 ******************************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "gw1ns2c.h"
#include <stdio.h>
#include <stdlib.h>

void UartInit(void);
void AdcInit(void);
void Delay_ms(__IO uint32_t delay_ms);

char buff[20];
volatile uint32_t counter;

int main()
{
	float adc_voltage = 0.0;
	uint32_t adc_data;
	
	SystemInit();//system init
  UartInit();//uart0 init
	
  printf("Uart Initial finished!\r\n");
  
	AdcInit();//adc init
	printf("Adc Initial:\r\n");
	
	adc_data = 0;              /* adc input */
	
	ADC_SetPowerStatus(ADC_STATUS_ON);  /* power on */
	
	/* Detect  Voltage */
	while(1)
	{
		/* Detect adc input */
		while(!ADC_GetEocStatus());
		adc_data = ADC_ReadData();
		
		/* Adc voltage */
		adc_voltage = (float)(adc_data)/(4096)*3.3;
		if(adc_voltage > 0.1)
		{
			printf("%d, ",adc_data);
			printf("%f\r\n",adc_voltage);
			//ADC_SetPowerStatus(ADC_STATUS_OFF); /* power off */
			//break;
		}
		Delay_ms(1000);
	}
}

void AdcInit(void)
{
	//Define ADC Init TypeDef
	ADC_InitTypeDef ADC_InitStruct;
	
	//Init ADC Init TypeDef
	ADC_InitStruct.ADC_Mode = ADC_MODE_SINGLE;//ADC mode
  ADC_InitStruct.ADC_Status = ADC_STATUS_OFF;//ADC power status
  ADC_InitStruct.ADC_Chsel = ADC_CHSEL_5;//ADC channel
  ADC_Init(&ADC_InitStruct);//Init
}

void UartInit(void)
{
  UART_InitTypeDef UART_InitStruct;
	
  UART_InitStruct.UART_Mode.UARTMode_Tx = ENABLE;
  UART_InitStruct.UART_Mode.UARTMode_Rx = ENABLE;
  UART_InitStruct.UART_Int.UARTInt_Tx = DISABLE;
  UART_InitStruct.UART_Int.UARTInt_Rx = DISABLE;
  UART_InitStruct.UART_Ovr.UARTOvr_Tx = DISABLE;
  UART_InitStruct.UART_Ovr.UARTOvr_Rx = DISABLE;
  UART_InitStruct.UART_Hstm = DISABLE;
  UART_InitStruct.UART_BaudRate = 115200;//Baud Rate
	
  UART_Init(UART0,&UART_InitStruct);
}

void Delay_ms(__IO uint32_t delay_ms)
{
  for(delay_ms=delay_ms*8500; delay_ms != 0; delay_ms--);
}
