
/*
 * *****************************************************************************************
 *
 * 		Copyright (C) 2014-2019 Gowin Semiconductor Technology Co.,Ltd.
 * 		
 * @file			main.c
 * @author		Embedded Development Team
 * @version		V1.3.0
 * @date			2019-10-1 09:00:00
 * @brief			Main program body.
 ******************************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "gw1ns2c.h"
#include <stdio.h>
#include <stdlib.h>

void UartInit(void);
void TimerInit(TIMER_TypeDef* TIMERx);
void Delay_ms(__IO uint32_t delay_ms);
char* int2str(int num,char*str,int radix);
char buff[20];
volatile uint32_t counter;

int main()
{   
  int num=0;
  NVIC_InitTypeDef InitTypeDef_NVIC;
	
  //Init System
  SystemInit();
	
  //Init Uart
  UartInit();
  UART_SendString(UART0,"\nUart Initial finished\r\n");
  UART_SendString(UART0,"\nTimer Initial:\r\n");
	
	//Init Timer
  TimerInit(TIMER0);
	
  counter=0;
	
  InitTypeDef_NVIC.NVIC_IRQChannel = TIMER0_IRQn;
  InitTypeDef_NVIC.NVIC_IRQChannelPreemptionPriority = 1;
  InitTypeDef_NVIC.NVIC_IRQChannelSubPriority = 1;
  InitTypeDef_NVIC.NVIC_IRQChannelCmd = ENABLE;
  NVIC_Init(&InitTypeDef_NVIC);

  UART_SendString(UART0,"\nNVIC ENABLE IRQ TIMER0\r\n");
  TIMER_EnableIRQ(TIMER0);
  UART_SendString(UART0,"\nTIMER0 IRQ ENABLE\r\n");
  TIMER_StartTimer(TIMER0);
  UART_SendString(UART0,"\nSTART TIMER0\r\n");
	
  while(1)
  {
    if(counter==2)
    {
      counter=0;
		 
      UART_SendString(UART0,"\r\n");
      UART_SendString(UART0,int2str(num,buff,10));
		 
      num++;
    }
		
    if(num==60)
	  {	
      num=0;
	  }
  }
}

void UartInit(void)
{
  UART_InitTypeDef UART_InitStruct;
	
  UART_InitStruct.UART_Mode.UARTMode_Tx = ENABLE;
  UART_InitStruct.UART_Mode.UARTMode_Rx = ENABLE;
  UART_InitStruct.UART_Int.UARTInt_Tx = DISABLE;
  UART_InitStruct.UART_Int.UARTInt_Rx = DISABLE;
  UART_InitStruct.UART_Ovr.UARTOvr_Tx = DISABLE;
  UART_InitStruct.UART_Ovr.UARTOvr_Rx = DISABLE;
  UART_InitStruct.UART_Hstm = DISABLE;
  UART_InitStruct.UART_BaudRate = 115200;//Baud Rate
	
  UART_Init(UART0,&UART_InitStruct);
}

void Delay_ms(__IO uint32_t delay_ms)
{
  for(delay_ms=delay_ms*8500; delay_ms != 0; delay_ms--);
}

void TimerInit(TIMER_TypeDef* TIMERx)
{ 
  TIMERx->INTCLEAR = 0;
  TIMER0->RELOAD=25000026;//Set the value of the Timmer 1s
  TIMER0->VALUE= TIMER0->RELOAD; //Set the init value
  TIMER0->CTRL=0;  // timmer interrupt
	
  UART_SendString(UART0,"TIMERx->INTCLEAR = 0;\r\n");
  UART_SendString(UART0,"TIMER0->RELOAD=25000026;\r\n");
  UART_SendString(UART0,"TIMERx->VALUE= TIMER0->RELOAD;\r\n");
  UART_SendString(UART0,"TIMERx->CTRL = 0;\r\n");
}

void TIMER0_Handler(void)
{
  if(TIMER_GetIRQStatus(TIMER0) != RESET)
  {
    counter++;
    TIMER_ClearIRQ(TIMER0);
  }
}

char* int2str(int num,char*str,int radix)
{
	char index[]="0123456789ABCDEF";
	unsigned unum;
	int i=0,j,k;
	char temp;

	if(radix==10&&num<0)
	{
		unum=(unsigned)-num;
		str[i++]='-';
	}
	else
	{
		unum=(unsigned)num;
	}

	do
	{
		str[i++]=index[unum%(unsigned)radix];
		unum/=radix;
	}while(unum);
	str[i]='\0';

	if(str[0]=='-')
	{
		k=1;
	}
	else
	{
		k=0;
	}
	
	for(j=k;j<=(i-1)/2;j++)
	{
		temp=str[j];
		str[j]=str[i-1+k-j];
		str[i-1+k-j]=temp;
	}
	
	return str;
}
