/*
 * *****************************************************************************************
 *
 * 		Copyright (C) 2014-2019 Gowin Semiconductor Technology Co.,Ltd.
 * 		
 * @file			digital_seg.c
 * @author		Embedded Development Team
 * @version		V1.3.0
 * @date			2019-10-1 09:00:00
 * @brief			Digital segment source file.
 ******************************************************************************************
 */
 
/* Includes ------------------------------------------------------------------*/
#include "digital_seg.h"
#include "systick.h"

/* Declaractions ------------------------------------------------------------------*/
static void DigitalSegNum(uint32_t dig_sel);

/* Functions ------------------------------------------------------------------*/
void DigitalSegInit(void)
{
	GPIO_InitTypeDef GPIO_InitType;
	
	GPIO_InitType.GPIO_Pin = DIG_SEL_1|DIG_SEL_2|DIG_SEL_3|DIG_SEL_4|
													 DIG_A|DIG_B|DIG_C|DIG_D|DIG_E|DIG_F|DIG_G|
													 LED1|LED2|LED3|LED4;
	GPIO_InitType.GPIO_Mode = GPIO_Mode_OUT;
	GPIO_InitType.GPIO_Int = GPIO_Int_Disable;
	
	GPIO_Init(GPIO0,&GPIO_InitType);
	
	GPIO_WriteBits(GPIO0,0xFFFFFFFF);
}

void DigitalSegDisplay(void)
{
	GPIO_ResetBit(GPIO0,LED1);
	DigitalSegNum(DIG_SEL_1);
	GPIO_SetBit(GPIO0,LED1);
	
	GPIO_ResetBit(GPIO0,LED2);
	DigitalSegNum(DIG_SEL_2);
	GPIO_SetBit(GPIO0,LED2);
	
	GPIO_ResetBit(GPIO0,LED3);
	DigitalSegNum(DIG_SEL_3);
	GPIO_SetBit(GPIO0,LED3);
	
	GPIO_ResetBit(GPIO0,LED4);
	DigitalSegNum(DIG_SEL_4);
	GPIO_SetBit(GPIO0,LED4);
}

static void DigitalSegNum(uint32_t dig_sel)
{
	uint8_t num = 0;
	switch(dig_sel)
	{
		case DIG_SEL_1:
			num = 1;
			break;
		case DIG_SEL_2:
			num = 2;
			break;
		case DIG_SEL_3:
			num = 3;
			break;
		case DIG_SEL_4:
			num = 4;
			break;
		default:
			break;
	}
	
	//Enable digital segment.
	GPIO_ResetBit(GPIO0,dig_sel);
	
	//Number '1'
	printf("Digital Segment %d displays 1.\r\n",num);
	GPIO_ResetBit(GPIO0,DIG_B);
	GPIO_ResetBit(GPIO0,DIG_C);
	delay_ms(10);
	GPIO_SetBit(GPIO0,DIG_B);
	GPIO_SetBit(GPIO0,DIG_C);
	
	//Number '2'
	printf("Digital Segment %d displays 2.\r\n",num);
	GPIO_ResetBit(GPIO0,DIG_A);
	GPIO_ResetBit(GPIO0,DIG_B);
	GPIO_ResetBit(GPIO0,DIG_G);
	GPIO_ResetBit(GPIO0,DIG_E);
	GPIO_ResetBit(GPIO0,DIG_D);
	delay_ms(10);
	GPIO_SetBit(GPIO0,DIG_A);
	GPIO_SetBit(GPIO0,DIG_B);
	GPIO_SetBit(GPIO0,DIG_G);
	GPIO_SetBit(GPIO0,DIG_E);
	GPIO_SetBit(GPIO0,DIG_D);
	
	//Number '3'
	printf("Digital Segment %d displays 3.\r\n",num);
	GPIO_ResetBit(GPIO0,DIG_A);
	GPIO_ResetBit(GPIO0,DIG_B);
	GPIO_ResetBit(GPIO0,DIG_G);
	GPIO_ResetBit(GPIO0,DIG_C);
	GPIO_ResetBit(GPIO0,DIG_D);
	delay_ms(10);
	GPIO_SetBit(GPIO0,DIG_A);
	GPIO_SetBit(GPIO0,DIG_B);
	GPIO_SetBit(GPIO0,DIG_G);
	GPIO_SetBit(GPIO0,DIG_C);
	GPIO_SetBit(GPIO0,DIG_D);
	
	//Number '4'
	printf("Digital Segment %d displays 4.\r\n",num);
	GPIO_ResetBit(GPIO0,DIG_F);
	GPIO_ResetBit(GPIO0,DIG_G);
	GPIO_ResetBit(GPIO0,DIG_B);
	GPIO_ResetBit(GPIO0,DIG_C);
	delay_ms(10);
	GPIO_SetBit(GPIO0,DIG_F);
	GPIO_SetBit(GPIO0,DIG_G);
	GPIO_SetBit(GPIO0,DIG_B);
	GPIO_SetBit(GPIO0,DIG_C);
	
	//Number '5'
	printf("Digital Segment %d displays 5.\r\n",num);
	GPIO_ResetBit(GPIO0,DIG_A);
	GPIO_ResetBit(GPIO0,DIG_F);
	GPIO_ResetBit(GPIO0,DIG_G);
	GPIO_ResetBit(GPIO0,DIG_C);
	GPIO_ResetBit(GPIO0,DIG_D);
	delay_ms(10);
	GPIO_SetBit(GPIO0,DIG_A);
	GPIO_SetBit(GPIO0,DIG_F);
	GPIO_SetBit(GPIO0,DIG_G);
	GPIO_SetBit(GPIO0,DIG_C);
	GPIO_SetBit(GPIO0,DIG_D);
	
	//Number '6'
	printf("Digital Segment %d displays 6.\r\n",num);
	GPIO_ResetBit(GPIO0,DIG_A);
	GPIO_ResetBit(GPIO0,DIG_F);
	GPIO_ResetBit(GPIO0,DIG_E);
	GPIO_ResetBit(GPIO0,DIG_D);
	GPIO_ResetBit(GPIO0,DIG_C);
	GPIO_ResetBit(GPIO0,DIG_G);
	delay_ms(10);
	GPIO_SetBit(GPIO0,DIG_A);
	GPIO_SetBit(GPIO0,DIG_F);
	GPIO_SetBit(GPIO0,DIG_E);
	GPIO_SetBit(GPIO0,DIG_D);
	GPIO_SetBit(GPIO0,DIG_C);
	GPIO_SetBit(GPIO0,DIG_G);
	
	//Number '7'
	printf("Digital Segment %d displays 7.\r\n",num);
	GPIO_ResetBit(GPIO0,DIG_A);
	GPIO_ResetBit(GPIO0,DIG_B);
	GPIO_ResetBit(GPIO0,DIG_C);
	delay_ms(10);
	GPIO_SetBit(GPIO0,DIG_A);
	GPIO_SetBit(GPIO0,DIG_B);
	GPIO_SetBit(GPIO0,DIG_C);
	
	//Number '8'
	printf("Digital Segment %d displays 8.\r\n",num);
	GPIO_ResetBit(GPIO0,DIG_A);
	GPIO_ResetBit(GPIO0,DIG_B);
	GPIO_ResetBit(GPIO0,DIG_C);
	GPIO_ResetBit(GPIO0,DIG_D);
	GPIO_ResetBit(GPIO0,DIG_E);
	GPIO_ResetBit(GPIO0,DIG_F);
	GPIO_ResetBit(GPIO0,DIG_G);
	delay_ms(10);
	GPIO_SetBit(GPIO0,DIG_A);
	GPIO_SetBit(GPIO0,DIG_B);
	GPIO_SetBit(GPIO0,DIG_C);
	GPIO_SetBit(GPIO0,DIG_D);
	GPIO_SetBit(GPIO0,DIG_E);
	GPIO_SetBit(GPIO0,DIG_F);
	GPIO_SetBit(GPIO0,DIG_G);
	
	//Number '9'
	printf("Digital Segment %d displays 9.\r\n",num);
	GPIO_ResetBit(GPIO0,DIG_A);
	GPIO_ResetBit(GPIO0,DIG_B);
	GPIO_ResetBit(GPIO0,DIG_C);
	GPIO_ResetBit(GPIO0,DIG_D);
	GPIO_ResetBit(GPIO0,DIG_F);
	GPIO_ResetBit(GPIO0,DIG_G);
	delay_ms(10);
	GPIO_SetBit(GPIO0,DIG_A);
	GPIO_SetBit(GPIO0,DIG_B);
	GPIO_SetBit(GPIO0,DIG_C);
	GPIO_SetBit(GPIO0,DIG_D);
	GPIO_SetBit(GPIO0,DIG_F);
	GPIO_SetBit(GPIO0,DIG_G);
	
	//Number '0'
	printf("Digital Segment %d displays 0.\r\n",num);
	GPIO_ResetBit(GPIO0,DIG_A);
	GPIO_ResetBit(GPIO0,DIG_B);
	GPIO_ResetBit(GPIO0,DIG_C);
	GPIO_ResetBit(GPIO0,DIG_D);
	GPIO_ResetBit(GPIO0,DIG_E);
	GPIO_ResetBit(GPIO0,DIG_F);
	delay_ms(10);
	GPIO_SetBit(GPIO0,DIG_A);
	GPIO_SetBit(GPIO0,DIG_B);
	GPIO_SetBit(GPIO0,DIG_C);
	GPIO_SetBit(GPIO0,DIG_D);
	GPIO_SetBit(GPIO0,DIG_E);
	GPIO_SetBit(GPIO0,DIG_F);
	
	//Disable digital segment.
	GPIO_SetBit(GPIO0,dig_sel);
}	
